@@ -1,6 +1,7 @@
 import re
 import os.path
 from collections import namedtuple
+from shutil import copyfile
 from eloquentarduino.jupyter.project.ArduinoCli import ArduinoCli
 
 
@@ -26,10 +27,9 @@ class Board:
         """Set board model
             Get the best match from the arduino-cli list of supported boards"""
         # parse known boards from arduino-cli
-        known_boards = self.cli(['board', 'listall']).lines
-        known_boards = [re.split(r'    +', line) for line in known_boards]
-        known_boards = [board for board in known_boards if len(board) == 2]
-        known_boards = [self.BoardModel(name=board[0], fqbn=board[1]) for board in known_boards]
+        lines = self.cli(['board', 'listall']).lines
+        board_regex_matches = [re.search(r'^(.+?)\s+([^ :]+?:[^ :]+?:[^ :]+?)$', line) for line in lines]
+        known_boards = [self.BoardModel(name=match.group(1), fqbn=match.group(2)) for match in board_regex_matches if match is not None]
         known_boards_names = [board.name for board in known_boards]
         # try exact match on name
         try:
@@ -39,6 +39,7 @@ class Board:
             self.project.log('Using it')
         except ValueError:
             # try partial match
+            i = -1
             self.project.log('Board [%s] not known, looking for best match...' % model_pattern)
             for i, model in enumerate(self._match_model(known_boards, model_pattern)):
                 self.project.log('Found a match: %s (%s)' % (model.name, model.fqbn))
@@ -81,22 +82,35 @@ class Board:
 
     def cli(self, arguments):
         """Execute arduino-cli command"""
-        self.project.log('[arduino-cli]', *arguments)
-        return ArduinoCli(arguments, path=self.cli_path)
+        return ArduinoCli(arguments, project=self.project, cli_path=self.cli_path, cwd=self.project.path)
+
+    def self_check(self):
+        """Assert that the arduino-cli is working fine"""
+        self.cli(['version'])
+        return True
 
     def compile(self):
         """Compile sketch"""
         self.project.assert_name()
         self.assert_model()
-        arguments = ['compile', '--verify', '-b', self.model.fqbn, os.path.abspath(os.path.dirname(self.project.ino_path))]
-        return self.cli(arguments)
+        arguments = ['compile', '--verify', '-b', self.model.fqbn]
+        ret = self.cli(arguments)
+        # hugly hack to make it work with paths containing spaces
+        # arduino-cli complains about a "..ino.df" file not found into the build folder
+        # so we rename the "{project_name}.dfu" to "..ino.dfu"
+        fqbn = self.model.fqbn.replace(':', '.')
+        original_file = os.path.abspath(os.path.join(self.project.path, 'build', fqbn, '%s.dfu' % self.project.ino_name))
+        hacky_file = os.path.abspath(os.path.join(self.project.path, 'build', fqbn, '..ino.dfu'))
+        self.project.log('hacky uploading workaround: renaming %s to %s' % (original_file, hacky_file))
+        copyfile(original_file, hacky_file)
+        return ret
 
     def upload(self):
         """Upload sketch"""
         self.project.assert_name()
         self.assert_model()
         assert self.port is not None, 'You MUST set a board port'
-        arguments = ['upload', '-b', self.model.fqbn, '-p', self.port, os.path.abspath(self.project.ino_path)]
+        arguments = ['upload', '-b', self.model.fqbn, '-p', self.port, '.']
         return self.cli(arguments)
 
     def _match_model(self, known_boards, pattern):
