@@ -9,7 +9,9 @@ def prettify(code):
     '''
     A super simple C code prettifier
     :param code: the raw C code
+    :type code: str
     :return: the prettified C code
+    :rtype str
     '''
     pretty = []
     indent = 0
@@ -43,9 +45,13 @@ def jinja(template_name, template_data={}, pretty=False):
     Render a Jinja template
 
     :param template_name: the path of the template relative to the 'templates' directory
-    :param template_data: data to pass to the template
-    :param pretty: wether to prettify the code
+    :type template_name: str
+    :param template_data: data to pass to the template, defaults to {}
+    :type template_data: dict
+    :param pretty: wether to prettify the code, defaults to False
+    :type pretty: bool
     :return: the rendered template
+    :rtype str
     """
     dir_path = os.path.dirname(os.path.realpath(__file__))
     loader = Environment(loader=FileSystemLoader(os.path.join(dir_path, '..', 'templates')))
